#import "TextFileWriterPatch.h"


@implementation TextFileWriterPatch : QCPatch

+ (int)executionMode
{
	return 1;
}
+ (BOOL)allowsSubpatches
{
	return NO;
}
+ (int)timeMode
{
	return 1;
}


- (id)initWithIdentifier:(id)fp8
{
	return [super initWithIdentifier:fp8];
}
- (id)attributes
{
	NSMutableDictionary *at=[[super attributes] mutableCopy];
	[at setObject:@"Kineme Text File Writer" forKey:@"name"];
	return at;
}


- (id)setup:(QCOpenGLContext *)context
{
	return context;
}
- (void)cleanup:(QCOpenGLContext *)context
{
}


- (void)enable:(QCOpenGLContext *)context
{
	oldValue=FALSE;
}
- (void)disable:(QCOpenGLContext *)context
{
}


- (BOOL)execute:(QCOpenGLContext *)context time:(double)time arguments:(NSDictionary *)arguments
{
	if( [[[self->_executionRuntime context] options] objectForKey:@"context.noNetworkConnections"] != 0 )
		return YES;


	// write on rising edge
	if([inputSignal booleanValue] == TRUE && oldValue == FALSE)
	{
		NSString *text = [inputText stringValue];
		NSString *path = [inputFile stringValue];

		if([path length] != 0)
		{
			// is it an absolute path?  if so, don't do anything
			if([path characterAtIndex:0] != '/')
			{
				if([path characterAtIndex:0] != '~')
				{
					// not absolute and not ~-ified, must be composition relative
					NSDictionary *options = [_executionRuntime options];
					path = [NSString stringWithFormat:@"%@/%@",[options objectForKey:@"runtime.resourcesPath"],path];
				}
				else	// it is a ~ directory, expand it
					path = [path stringByExpandingTildeInPath];
			}
			
			[[NSFileManager defaultManager] createFileAtPath:path
				contents:(NSData*)text
				attributes:nil];
		}
	}
	
	oldValue = [inputSignal booleanValue];
	return YES;
}

@end
